BorshStringSized class

String Sized

An annotation for fixed-length strings.

@BorshStringSized(10)
final String property;
Inheritance

Constructors

BorshStringSized(int byteLength, [BufferEncoding? encoding])
Creates an annotation for a fixed-length string.
const

Properties

byteLength → int
The encoded byte length.
final
encoding → BufferEncoding?
The encoding.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited