BorshBoolCodec class

Bool Codec

A codec for boolean data types.

Inheritance
Mixed-in types

Constructors

BorshBoolCodec()
Creates a codec for boolean data types.
const

Properties

byteLength → int
The number of bytes required to store any instance of T (i.e. max size).
no setteroverride
decoder → BorshDecoder<bool>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → BorshEncoder<bool>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, bool>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cOption() → BorshOptionSizedCodec<bool>
Converts this codec to an c-option code of type T.
inherited
decode(Iterable<int> encoded) → bool
Decodes encoded data.
inherited
encode(bool input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<bool, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option() → BorshOptionSizedCodec<bool>
Converts this codec to an option code of type T.
inherited
pack(BufferWriter buffer, bool input) → void
Writes input to buffer.
inherited
size(bool input) → int
Returns the serialized byte length of input.
override
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → bool
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited