BorshMapCodec<K, V> class

Map Codec

A codec for map data types.

Inheritance

Constructors

BorshMapCodec(BorshCodec<K> keySubtype, BorshCodec<V> valueSubtype)
Creates a codec for map data types.
const

Properties

decoder → BorshDecoder<Map<K, V>>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → BorshEncoder<Map<K, V>>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, Map<K, V>>
Inverts this.
no setterinherited
keySubtype → BorshCodec<K>
The key data type's codec.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueSubtype → BorshCodec<V>
The value data type's codec.
final

Methods

decode(Iterable<int> encoded) → Map<K, V>
Decodes encoded data.
inherited
encode(Map<K, V> input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<Map<K, V>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(BufferWriter buffer, Map<K, V> input) → void
Writes input to buffer.
inherited
size(Map<K, V> input) → int
Returns the serialized byte length of input.
override
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → Map<K, V>
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited