BorshRustEnumSizedCodec<T> class

Rust Enum Sized Codec

A codec for complex Rust style enums with sized data types (tuple or struct constructors).

Inheritance
Mixed-in types

Constructors

BorshRustEnumSizedCodec(List<BorshCodecFixedSized<T>?> variants)
Creates a codec for complex Rust style enums with sized data types (tuple or struct constructors).
const

Properties

byteLength → int
The number of bytes required to store any instance of T (i.e. max size).
no setteroverride
decoder → BorshRustEnumSizedDecoder<T>
Returns the decoder of this, converting from T to S.
no setter
encoder → BorshRustEnumSizedEncoder<T>
Returns the encoder from S to T.
no setter
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Iterable<int>, RustEnum<T>>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variants → List<BorshCodecFixedSized<T>?>
The enum variants codecs.
finalinherited

Methods

cOption() → BorshOptionSizedCodec<RustEnum<T>>
Converts this codec to an c-option code of type T.
inherited
decode(Iterable<int> encoded) → RustEnum<T>
Decodes encoded data.
inherited
encode(RustEnum<T> input) → Iterable<int>
Encodes input.
inherited
fuse<R>(Codec<Iterable<int>, R> other) → Codec<RustEnum<T>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option() → BorshOptionSizedCodec<RustEnum<T>>
Converts this codec to an option code of type T.
inherited
pack(BufferWriter buffer, RustEnum<T> input) → void
Writes input to buffer.
inherited
size(RustEnum input) → int
Returns the serialized byte length of input.
inherited
toString() → String
A string representation of this object.
inherited
unpack(BufferReader buffer) → RustEnum<T>
Reads T from buffer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited